"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AccountPersonalization(google.protobuf.message.Message):
    """A customization options mainly for frontend"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRAND_FIELD_NUMBER: builtins.int
    @property
    def brand(self) -> global___Brand: ...
    def __init__(
        self,
        *,
        brand: global___Brand | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["brand", b"brand"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["brand", b"brand"]) -> None: ...

global___AccountPersonalization = AccountPersonalization

class Brand(google.protobuf.message.Message):
    """A customization options for brand the qwak system with the customer brand"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGO_IMAGE_PATH_FIELD_NUMBER: builtins.int
    logo_image_path: builtins.str
    def __init__(
        self,
        *,
        logo_image_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["logo_image_path", b"logo_image_path"]) -> None: ...

global___Brand = Brand
