# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/deployment/deployment_messages.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.deployment import deployment_pb2 as qwak_dot_deployment_dot_deployment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/deployment/deployment_messages.proto\x12\x1aqwak.deployment.management\x1a qwak/deployment/deployment.proto\"\xb5\x02\n\x1bModelDeploymentNotification\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x11\n\tbranch_id\x18\x02 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x43\n\x0fhosting_service\x18\x04 \x01(\x0b\x32*.qwak.deployment.management.HostingService\x12\x41\n\x06status\x18\x05 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x15\n\rdeployment_id\x18\x06 \x01(\t\x12\x1b\n\x13\x66\x61ilure_reason_code\x18\x07 \x01(\t\x12!\n\x19\x66\x61ilure_technical_details\x18\x08 \x01(\tB)\n%com.qwak.ai.management.deployment.apiP\x01\x62\x06proto3')



_MODELDEPLOYMENTNOTIFICATION = DESCRIPTOR.message_types_by_name['ModelDeploymentNotification']
ModelDeploymentNotification = _reflection.GeneratedProtocolMessageType('ModelDeploymentNotification', (_message.Message,), {
  'DESCRIPTOR' : _MODELDEPLOYMENTNOTIFICATION,
  '__module__' : 'qwak.deployment.deployment_messages_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.ModelDeploymentNotification)
  })
_sym_db.RegisterMessage(ModelDeploymentNotification)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001'
  _MODELDEPLOYMENTNOTIFICATION._serialized_start=108
  _MODELDEPLOYMENTNOTIFICATION._serialized_end=417
# @@protoc_insertion_point(module_scope)
