"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.admiral.secret.v0.secret_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SetEnvironmentSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> qwak.admiral.secret.v0.secret_pb2.SetUserEnvironmentSecretOptions: ...
    def __init__(
        self,
        *,
        options: qwak.admiral.secret.v0.secret_pb2.SetUserEnvironmentSecretOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___SetEnvironmentSecretRequest = SetEnvironmentSecretRequest

class SetEnvironmentSecretResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetEnvironmentSecretResponse = SetEnvironmentSecretResponse

class DeleteEnvironmentSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> qwak.admiral.secret.v0.secret_pb2.EnvironmentSecretIdentifier:
        """Secret identifier"""
    def __init__(
        self,
        *,
        identifier: qwak.admiral.secret.v0.secret_pb2.EnvironmentSecretIdentifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> None: ...

global___DeleteEnvironmentSecretRequest = DeleteEnvironmentSecretRequest

class DeleteEnvironmentSecretResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteEnvironmentSecretResponse = DeleteEnvironmentSecretResponse

class ListAccountSecretsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAccountSecretsRequest = ListAccountSecretsRequest

class ListAccountSecretsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_SECRETS_FIELD_NUMBER: builtins.int
    @property
    def account_secrets(self) -> qwak.admiral.secret.v0.secret_pb2.AccountSecrets:
        """Secrets of account"""
    def __init__(
        self,
        *,
        account_secrets: qwak.admiral.secret.v0.secret_pb2.AccountSecrets | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_secrets", b"account_secrets"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_secrets", b"account_secrets"]) -> None: ...

global___ListAccountSecretsResponse = ListAccountSecretsResponse
