"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.features.feature_set_state_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetFeatureSetStateByIdV1Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    RUN_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    """Feature id"""
    run_id: builtins.int
    """Run id"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
        run_id: builtins.int = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "feature_set_id", b"feature_set_id", "run_id", b"run_id"]) -> None: ...

global___GetFeatureSetStateByIdV1Request = GetFeatureSetStateByIdV1Request

class GetFeatureSetStateByIdV1Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_STATE_FIELD_NUMBER: builtins.int
    @property
    def feature_set_state(self) -> qwak.feature_store.features.feature_set_state_pb2.FeatureSetState:
        """The state info"""
    def __init__(
        self,
        *,
        feature_set_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> None: ...

global___GetFeatureSetStateByIdV1Response = GetFeatureSetStateByIdV1Response

class GetFeatureSetStateByNameV1Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    RUN_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature name"""
    run_id: builtins.int
    """Run id"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
        run_id: builtins.int = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "feature_set_name", b"feature_set_name", "run_id", b"run_id"]) -> None: ...

global___GetFeatureSetStateByNameV1Request = GetFeatureSetStateByNameV1Request

class GetFeatureSetStateByNameV1Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_STATE_FIELD_NUMBER: builtins.int
    @property
    def feature_set_state(self) -> qwak.feature_store.features.feature_set_state_pb2.FeatureSetState:
        """The state info"""
    def __init__(
        self,
        *,
        feature_set_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> None: ...

global___GetFeatureSetStateByNameV1Response = GetFeatureSetStateByNameV1Response

class GetFeatureSetStatesListV1Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetFeatureSetStatesListV1Request = GetFeatureSetStatesListV1Request

class GetFeatureSetStatesListV1Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_STATE_FIELD_NUMBER: builtins.int
    @property
    def feature_set_state(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.features.feature_set_state_pb2.FeatureSetState]:
        """List of the features states"""
    def __init__(
        self,
        *,
        feature_set_state: collections.abc.Iterable[qwak.feature_store.features.feature_set_state_pb2.FeatureSetState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> None: ...

global___GetFeatureSetStatesListV1Response = GetFeatureSetStatesListV1Response

class UpdateFeatureSetStateV1Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_STATE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    @property
    def feature_set_state(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.features.feature_set_state_pb2.FeatureSetState]:
        """Updated feature set state"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        feature_set_state: collections.abc.Iterable[qwak.feature_store.features.feature_set_state_pb2.FeatureSetState] | None = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "feature_set_state", b"feature_set_state"]) -> None: ...

global___UpdateFeatureSetStateV1Request = UpdateFeatureSetStateV1Request

class UpdateFeatureSetStateV1Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateFeatureSetStateV1Response = UpdateFeatureSetStateV1Response

class DeleteFeatureSetStateV1Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteFeatureSetStateV1Response = DeleteFeatureSetStateV1Response

class DeleteFeatureSetStateV1Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_id", b"feature_set_id"]) -> None: ...

global___DeleteFeatureSetStateV1Request = DeleteFeatureSetStateV1Request
