"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.feature_store.repository.common.platform_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PlatformDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLATFORM_SETTINGS_FIELD_NUMBER: builtins.int
    AUTH_TYPE_FIELD_NUMBER: builtins.int
    @property
    def platform_settings(self) -> qwak.feature_store.repository.common.platform_pb2.PlatformSettings:
        """Platform settings"""
    @property
    def auth_type(self) -> global___AuthType:
        """Auth type"""
    def __init__(
        self,
        *,
        platform_settings: qwak.feature_store.repository.common.platform_pb2.PlatformSettings | None = ...,
        auth_type: global___AuthType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "platform_settings", b"platform_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "platform_settings", b"platform_settings"]) -> None: ...

global___PlatformDetails = PlatformDetails

class AuthType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_ID_FIELD_NUMBER: builtins.int
    token_id: builtins.str
    def __init__(
        self,
        *,
        token_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token_id", b"token_id", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_id", b"token_id", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["token_id"] | None: ...

global___AuthType = AuthType
