# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/jobs/reports/report.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.execution.v1 import backfill_pb2 as qwak_dot_execution_dot_v1_dot_backfill__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/execution/v1/jobs/reports/report.proto\x12,qwak.feature.store.execution.v1.jobs.reports\x1a qwak/execution/v1/backfill.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"+\n\x12\x46\x61ilureInformation\x12\x15\n\rerror_message\x18\x01 \x01(\t\"\xd5\x01\n\x19\x42\x61tchIngestionJobMetadata\x12\x38\n\x14\x62\x61tch_execution_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1bingestion_window_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x19ingestion_window_end_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xbe\x03\n\x18\x42\x61tchBackfillJobMetadata\x12\x19\n\x11num_interval_rows\x18\x01 \x01(\x03\x12\x44\n\rbackfill_spec\x18\x02 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillSpec\x12\x41\n\x1doffline_processing_start_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1boffline_processing_end_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x1conline_processing_start_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x1aonline_processing_end_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17last_batch_logical_date\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"(\n\x14StreamingJobMetadata\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\x04\"!\n\x1fStreamingAggregationJobMetadata\"\xb6\x08\n\tJobReport\x12k\n\x18\x62\x61tch_ingestion_metadata\x18\x01 \x01(\x0b\x32G.qwak.feature.store.execution.v1.jobs.reports.BatchIngestionJobMetadataH\x00\x12\x64\n\x16streaming_job_metadata\x18\x02 \x01(\x0b\x32\x42.qwak.feature.store.execution.v1.jobs.reports.StreamingJobMetadataH\x00\x12t\n\x1bstreaming_aggr_job_metadata\x18\x03 \x01(\x0b\x32M.qwak.feature.store.execution.v1.jobs.reports.StreamingAggregationJobMetadataH\x00\x12m\n\x1b\x62\x61tch_backfill_job_metadata\x18\x04 \x01(\x0b\x32\x46.qwak.feature.store.execution.v1.jobs.reports.BatchBackfillJobMetadataH\x00\x12\x1c\n\x14num_affected_records\x18\x05 \x01(\x03\x12\x32\n\x0erun_start_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0crun_end_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\rlegacy_run_id\x18\x08 \x01(\x03H\x01\x12\x16\n\x0c\x65xecution_id\x18\t \x01(\tH\x01\x12\x16\n\x0e\x65nvironment_id\x18\n \x01(\t\x12\x15\n\rfeatureset_id\x18\x0b \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x0c \x01(\t\x12G\n\x06status\x18\r \x01(\x0e\x32\x37.qwak.feature.store.execution.v1.jobs.reports.JobStatus\x12Z\n\njob_labels\x18\x0e \x03(\x0b\x32\x46.qwak.feature.store.execution.v1.jobs.reports.JobReport.JobLabelsEntry\x12\x0e\n\x06job_id\x18\x0f \x01(\t\x12P\n\x04info\x18\x10 \x01(\x0b\x32@.qwak.feature.store.execution.v1.jobs.reports.FailureInformationH\x02\x1a\x30\n\x0eJobLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x13\n\x11job_metadata_typeB\x16\n\x14\x65xecution_identifierB\x0e\n\x0c\x66\x61ilure_info*m\n\tJobStatus\x12\x16\n\x12JOB_STATUS_INVALID\x10\x00\x12\x16\n\x12JOB_STATUS_SUCCESS\x10\x01\x12\x16\n\x12JOB_STATUS_FAILURE\x10\x02\x12\x18\n\x14JOB_STATUS_TOO_EARLY\x10\x03\x42\x36\n2com.qwak.ai.features.execution.api.v1.jobs.reportsP\x01\x62\x06proto3')

_JOBSTATUS = DESCRIPTOR.enum_types_by_name['JobStatus']
JobStatus = enum_type_wrapper.EnumTypeWrapper(_JOBSTATUS)
JOB_STATUS_INVALID = 0
JOB_STATUS_SUCCESS = 1
JOB_STATUS_FAILURE = 2
JOB_STATUS_TOO_EARLY = 3


_FAILUREINFORMATION = DESCRIPTOR.message_types_by_name['FailureInformation']
_BATCHINGESTIONJOBMETADATA = DESCRIPTOR.message_types_by_name['BatchIngestionJobMetadata']
_BATCHBACKFILLJOBMETADATA = DESCRIPTOR.message_types_by_name['BatchBackfillJobMetadata']
_STREAMINGJOBMETADATA = DESCRIPTOR.message_types_by_name['StreamingJobMetadata']
_STREAMINGAGGREGATIONJOBMETADATA = DESCRIPTOR.message_types_by_name['StreamingAggregationJobMetadata']
_JOBREPORT = DESCRIPTOR.message_types_by_name['JobReport']
_JOBREPORT_JOBLABELSENTRY = _JOBREPORT.nested_types_by_name['JobLabelsEntry']
FailureInformation = _reflection.GeneratedProtocolMessageType('FailureInformation', (_message.Message,), {
  'DESCRIPTOR' : _FAILUREINFORMATION,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.FailureInformation)
  })
_sym_db.RegisterMessage(FailureInformation)

BatchIngestionJobMetadata = _reflection.GeneratedProtocolMessageType('BatchIngestionJobMetadata', (_message.Message,), {
  'DESCRIPTOR' : _BATCHINGESTIONJOBMETADATA,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.BatchIngestionJobMetadata)
  })
_sym_db.RegisterMessage(BatchIngestionJobMetadata)

BatchBackfillJobMetadata = _reflection.GeneratedProtocolMessageType('BatchBackfillJobMetadata', (_message.Message,), {
  'DESCRIPTOR' : _BATCHBACKFILLJOBMETADATA,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.BatchBackfillJobMetadata)
  })
_sym_db.RegisterMessage(BatchBackfillJobMetadata)

StreamingJobMetadata = _reflection.GeneratedProtocolMessageType('StreamingJobMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGJOBMETADATA,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.StreamingJobMetadata)
  })
_sym_db.RegisterMessage(StreamingJobMetadata)

StreamingAggregationJobMetadata = _reflection.GeneratedProtocolMessageType('StreamingAggregationJobMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGAGGREGATIONJOBMETADATA,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.StreamingAggregationJobMetadata)
  })
_sym_db.RegisterMessage(StreamingAggregationJobMetadata)

JobReport = _reflection.GeneratedProtocolMessageType('JobReport', (_message.Message,), {

  'JobLabelsEntry' : _reflection.GeneratedProtocolMessageType('JobLabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOBREPORT_JOBLABELSENTRY,
    '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
    # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.JobReport.JobLabelsEntry)
    })
  ,
  'DESCRIPTOR' : _JOBREPORT,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.JobReport)
  })
_sym_db.RegisterMessage(JobReport)
_sym_db.RegisterMessage(JobReport.JobLabelsEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n2com.qwak.ai.features.execution.api.v1.jobs.reportsP\001'
  _JOBREPORT_JOBLABELSENTRY._options = None
  _JOBREPORT_JOBLABELSENTRY._serialized_options = b'8\001'
  _JOBSTATUS._serialized_start=2028
  _JOBSTATUS._serialized_end=2137
  _FAILUREINFORMATION._serialized_start=160
  _FAILUREINFORMATION._serialized_end=203
  _BATCHINGESTIONJOBMETADATA._serialized_start=206
  _BATCHINGESTIONJOBMETADATA._serialized_end=419
  _BATCHBACKFILLJOBMETADATA._serialized_start=422
  _BATCHBACKFILLJOBMETADATA._serialized_end=868
  _STREAMINGJOBMETADATA._serialized_start=870
  _STREAMINGJOBMETADATA._serialized_end=910
  _STREAMINGAGGREGATIONJOBMETADATA._serialized_start=912
  _STREAMINGAGGREGATIONJOBMETADATA._serialized_end=945
  _JOBREPORT._serialized_start=948
  _JOBREPORT._serialized_end=2026
  _JOBREPORT_JOBLABELSENTRY._serialized_start=1917
  _JOBREPORT_JOBLABELSENTRY._serialized_end=1965
# @@protoc_insertion_point(module_scope)
