# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/cluster/v2/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import runtime_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_runtime__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import network_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_network__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/administration/cluster/v2/cluster.proto\x12\x1eqwak.administration.cluster.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x41qwak/administration/runtime_configuration/v0/runtime_config.proto\x1a\x41qwak/administration/runtime_configuration/v0/network_config.proto\"\xbb\x01\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12K\n\rconfiguration\x18\x03 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.ClusterConfiguration\x12I\n\x10\x63luster_metadata\x18\x04 \x01(\x0b\x32/.qwak.administration.cluster.v2.ClusterMetadata\"\xa5\x01\n\x0f\x43lusterMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\"\xb1\x02\n\x14\x43lusterConfiguration\x12\\\n\x19self_hosted_configuration\x18\x01 \x01(\x0b\x32\x37.qwak.administration.cluster.v2.SelfHostedConfigurationH\x00\x12^\n\x1aself_service_configuration\x18\x02 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.SelfServiceConfigurationH\x00\x12S\n\x14hybrid_configuration\x18\x03 \x01(\x0b\x32\x33.qwak.administration.cluster.v2.HybridConfigurationH\x00\x42\x06\n\x04type\"n\n\x17SelfHostedConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"o\n\x18SelfServiceConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"j\n\x13HybridConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"\xf2\x01\n\x14RuntimeConfiguration\x12\x61\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.RuntimeConfiguration\x12w\n\x15network_configuration\x18\x02 \x01(\x0b\x32X.qwak.administration.runtime_configuration.v0.network_config.ClusterNetworkConfiguration\"y\n\x0b\x43lusterSpec\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12T\n\x12\x63onfiguration_spec\x18\x02 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.ClusterConfigurationSpec\"\xc1\x02\n\x18\x43lusterConfigurationSpec\x12`\n\x19self_hosted_configuration\x18\x01 \x01(\x0b\x32;.qwak.administration.cluster.v2.SelfHostedConfigurationSpecH\x00\x12\x62\n\x1aself_service_configuration\x18\x02 \x01(\x0b\x32<.qwak.administration.cluster.v2.SelfServiceConfigurationSpecH\x00\x12W\n\x14hybrid_configuration\x18\x03 \x01(\x0b\x32\x37.qwak.administration.cluster.v2.HybridConfigurationSpecH\x00\x42\x06\n\x04type\"v\n\x1bSelfHostedConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"w\n\x1cSelfServiceConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"r\n\x17HybridConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"\xf6\x01\n\x18RuntimeConfigurationSpec\x12\x61\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.RuntimeConfiguration\x12w\n\x15network_configuration\x18\x02 \x01(\x0b\x32X.qwak.administration.runtime_configuration.v0.network_config.ClusterNetworkConfiguration\"V\n\x0c\x43lusterState\x12=\n\x05valid\x18\x01 \x01(\x0b\x32,.qwak.administration.cluster.v2.ClusterValidH\x00\x42\x07\n\x05state\"H\n\x0c\x43lusterValid\x12\x38\n\x07\x63luster\x18\x01 \x01(\x0b\x32\'.qwak.administration.cluster.v2.Cluster\"b\n\x0c\x43lusterBrief\x12R\n\x11installation_type\x18\x01 \x01(\x0e\x32\x37.qwak.administration.cluster.v2.ClusterInstallationType*\xbd\x01\n\x17\x43lusterInstallationType\x12%\n!CLUSTER_INSTALLATION_TYPE_INVALID\x10\x00\x12)\n%SELF_HOSTED_CLUSTER_INSTALLATION_TYPE\x10\x01\x12*\n&SELF_SERVICE_CLUSTER_INSTALLATION_TYPE\x10\x02\x12$\n HYBRID_CLUSTER_INSTALLATION_TYPE\x10\x03\x42\xb4\x01\n)com.qwak.ai.administration.api.cluster.v2P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/cluster/v2;cluster_v2b\x06proto3')

_CLUSTERINSTALLATIONTYPE = DESCRIPTOR.enum_types_by_name['ClusterInstallationType']
ClusterInstallationType = enum_type_wrapper.EnumTypeWrapper(_CLUSTERINSTALLATIONTYPE)
CLUSTER_INSTALLATION_TYPE_INVALID = 0
SELF_HOSTED_CLUSTER_INSTALLATION_TYPE = 1
SELF_SERVICE_CLUSTER_INSTALLATION_TYPE = 2
HYBRID_CLUSTER_INSTALLATION_TYPE = 3


_CLUSTER = DESCRIPTOR.message_types_by_name['Cluster']
_CLUSTERMETADATA = DESCRIPTOR.message_types_by_name['ClusterMetadata']
_CLUSTERCONFIGURATION = DESCRIPTOR.message_types_by_name['ClusterConfiguration']
_SELFHOSTEDCONFIGURATION = DESCRIPTOR.message_types_by_name['SelfHostedConfiguration']
_SELFSERVICECONFIGURATION = DESCRIPTOR.message_types_by_name['SelfServiceConfiguration']
_HYBRIDCONFIGURATION = DESCRIPTOR.message_types_by_name['HybridConfiguration']
_RUNTIMECONFIGURATION = DESCRIPTOR.message_types_by_name['RuntimeConfiguration']
_CLUSTERSPEC = DESCRIPTOR.message_types_by_name['ClusterSpec']
_CLUSTERCONFIGURATIONSPEC = DESCRIPTOR.message_types_by_name['ClusterConfigurationSpec']
_SELFHOSTEDCONFIGURATIONSPEC = DESCRIPTOR.message_types_by_name['SelfHostedConfigurationSpec']
_SELFSERVICECONFIGURATIONSPEC = DESCRIPTOR.message_types_by_name['SelfServiceConfigurationSpec']
_HYBRIDCONFIGURATIONSPEC = DESCRIPTOR.message_types_by_name['HybridConfigurationSpec']
_RUNTIMECONFIGURATIONSPEC = DESCRIPTOR.message_types_by_name['RuntimeConfigurationSpec']
_CLUSTERSTATE = DESCRIPTOR.message_types_by_name['ClusterState']
_CLUSTERVALID = DESCRIPTOR.message_types_by_name['ClusterValid']
_CLUSTERBRIEF = DESCRIPTOR.message_types_by_name['ClusterBrief']
Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTER,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.Cluster)
  })
_sym_db.RegisterMessage(Cluster)

ClusterMetadata = _reflection.GeneratedProtocolMessageType('ClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERMETADATA,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterMetadata)
  })
_sym_db.RegisterMessage(ClusterMetadata)

ClusterConfiguration = _reflection.GeneratedProtocolMessageType('ClusterConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCONFIGURATION,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterConfiguration)
  })
_sym_db.RegisterMessage(ClusterConfiguration)

SelfHostedConfiguration = _reflection.GeneratedProtocolMessageType('SelfHostedConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _SELFHOSTEDCONFIGURATION,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.SelfHostedConfiguration)
  })
_sym_db.RegisterMessage(SelfHostedConfiguration)

SelfServiceConfiguration = _reflection.GeneratedProtocolMessageType('SelfServiceConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _SELFSERVICECONFIGURATION,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.SelfServiceConfiguration)
  })
_sym_db.RegisterMessage(SelfServiceConfiguration)

HybridConfiguration = _reflection.GeneratedProtocolMessageType('HybridConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _HYBRIDCONFIGURATION,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.HybridConfiguration)
  })
_sym_db.RegisterMessage(HybridConfiguration)

RuntimeConfiguration = _reflection.GeneratedProtocolMessageType('RuntimeConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMECONFIGURATION,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.RuntimeConfiguration)
  })
_sym_db.RegisterMessage(RuntimeConfiguration)

ClusterSpec = _reflection.GeneratedProtocolMessageType('ClusterSpec', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterSpec)
  })
_sym_db.RegisterMessage(ClusterSpec)

ClusterConfigurationSpec = _reflection.GeneratedProtocolMessageType('ClusterConfigurationSpec', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCONFIGURATIONSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterConfigurationSpec)
  })
_sym_db.RegisterMessage(ClusterConfigurationSpec)

SelfHostedConfigurationSpec = _reflection.GeneratedProtocolMessageType('SelfHostedConfigurationSpec', (_message.Message,), {
  'DESCRIPTOR' : _SELFHOSTEDCONFIGURATIONSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.SelfHostedConfigurationSpec)
  })
_sym_db.RegisterMessage(SelfHostedConfigurationSpec)

SelfServiceConfigurationSpec = _reflection.GeneratedProtocolMessageType('SelfServiceConfigurationSpec', (_message.Message,), {
  'DESCRIPTOR' : _SELFSERVICECONFIGURATIONSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.SelfServiceConfigurationSpec)
  })
_sym_db.RegisterMessage(SelfServiceConfigurationSpec)

HybridConfigurationSpec = _reflection.GeneratedProtocolMessageType('HybridConfigurationSpec', (_message.Message,), {
  'DESCRIPTOR' : _HYBRIDCONFIGURATIONSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.HybridConfigurationSpec)
  })
_sym_db.RegisterMessage(HybridConfigurationSpec)

RuntimeConfigurationSpec = _reflection.GeneratedProtocolMessageType('RuntimeConfigurationSpec', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMECONFIGURATIONSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.RuntimeConfigurationSpec)
  })
_sym_db.RegisterMessage(RuntimeConfigurationSpec)

ClusterState = _reflection.GeneratedProtocolMessageType('ClusterState', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERSTATE,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterState)
  })
_sym_db.RegisterMessage(ClusterState)

ClusterValid = _reflection.GeneratedProtocolMessageType('ClusterValid', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERVALID,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterValid)
  })
_sym_db.RegisterMessage(ClusterValid)

ClusterBrief = _reflection.GeneratedProtocolMessageType('ClusterBrief', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERBRIEF,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterBrief)
  })
_sym_db.RegisterMessage(ClusterBrief)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.cluster.v2P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/cluster/v2;cluster_v2'
  _CLUSTERINSTALLATIONTYPE._serialized_start=2807
  _CLUSTERINSTALLATIONTYPE._serialized_end=2996
  _CLUSTER._serialized_start=248
  _CLUSTER._serialized_end=435
  _CLUSTERMETADATA._serialized_start=438
  _CLUSTERMETADATA._serialized_end=603
  _CLUSTERCONFIGURATION._serialized_start=606
  _CLUSTERCONFIGURATION._serialized_end=911
  _SELFHOSTEDCONFIGURATION._serialized_start=913
  _SELFHOSTEDCONFIGURATION._serialized_end=1023
  _SELFSERVICECONFIGURATION._serialized_start=1025
  _SELFSERVICECONFIGURATION._serialized_end=1136
  _HYBRIDCONFIGURATION._serialized_start=1138
  _HYBRIDCONFIGURATION._serialized_end=1244
  _RUNTIMECONFIGURATION._serialized_start=1247
  _RUNTIMECONFIGURATION._serialized_end=1489
  _CLUSTERSPEC._serialized_start=1491
  _CLUSTERSPEC._serialized_end=1612
  _CLUSTERCONFIGURATIONSPEC._serialized_start=1615
  _CLUSTERCONFIGURATIONSPEC._serialized_end=1936
  _SELFHOSTEDCONFIGURATIONSPEC._serialized_start=1938
  _SELFHOSTEDCONFIGURATIONSPEC._serialized_end=2056
  _SELFSERVICECONFIGURATIONSPEC._serialized_start=2058
  _SELFSERVICECONFIGURATIONSPEC._serialized_end=2177
  _HYBRIDCONFIGURATIONSPEC._serialized_start=2179
  _HYBRIDCONFIGURATIONSPEC._serialized_end=2293
  _RUNTIMECONFIGURATIONSPEC._serialized_start=2296
  _RUNTIMECONFIGURATIONSPEC._serialized_end=2542
  _CLUSTERSTATE._serialized_start=2544
  _CLUSTERSTATE._serialized_end=2630
  _CLUSTERVALID._serialized_start=2632
  _CLUSTERVALID._serialized_end=2704
  _CLUSTERBRIEF._serialized_start=2706
  _CLUSTERBRIEF._serialized_end=2804
# @@protoc_insertion_point(module_scope)
