# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v0/environments/environment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.administration.v0.environments import configuration_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_configuration__pb2
from _qwak_proto.qwak.administration.v0.environments import personalization_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_personalization__pb2
from _qwak_proto.qwak.administration.account.v1 import account_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_account__pb2
from _qwak_proto.qwak.administration.cluster.v2 import cluster_pb2 as qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5qwak/administration/v0/environments/environment.proto\x12\x1fqwak.administration.environment\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x37qwak/administration/v0/environments/configuration.proto\x1a\x39qwak/administration/v0/environments/personalization.proto\x1a,qwak/administration/account/v1/account.proto\x1a,qwak/administration/cluster/v2/cluster.proto\"\xbe\x05\n\x0fQwakEnvironment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\ttenant_id\x18\x03 \x01(\tB\x02\x18\x01\x12\x12\n\naccount_id\x18\x08 \x01(\t\x12\x12\n\ncluster_id\x18\n \x01(\t\x12\x42\n\x0c\x61\x63\x63ount_tier\x18\x0b \x01(\x0e\x32,.qwak.administration.environment.AccountTier\x12\x46\n\x06status\x18\x04 \x01(\x0e\x32\x36.qwak.administration.environment.QwakEnvironmentStatus\x12T\n\rconfiguration\x18\x05 \x01(\x0b\x32=.qwak.administration.environment.QwakEnvironmentConfiguration\x12T\n\x0fpersonalization\x18\t \x01(\x0b\x32;.qwak.administration.environment.EnvironmentPersonalization\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x0fjfrog_tenant_id\x18\x0c \x01(\tH\x00\x12\x38\n\x07\x61\x63\x63ount\x18\r \x01(\x0b\x32\'.qwak.administration.account.v1.Account\x12\x43\n\rcluster_brief\x18\x0e \x01(\x0b\x32,.qwak.administration.cluster.v2.ClusterBriefB\x1a\n\x18optional_jfrog_tenant_id\"8\n%EnvironmentApplicationUserCredentials\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t*w\n\x15QwakEnvironmentStatus\x12\x1e\n\x1a\x45NVIRONMENT_STATUS_INVALID\x10\x00\x12\x1d\n\x19\x45NVIRONMENT_STATUS_ACTIVE\x10\x01\x12\x1f\n\x1b\x45NVIRONMENT_STATUS_DISABLED\x10\x02*L\n\x0b\x41\x63\x63ountTier\x12\x18\n\x14\x41\x43\x43OUNT_TIER_INVALID\x10\x00\x12\x08\n\x04\x46REE\x10\x01\x12\r\n\tVALIDATED\x10\x02\x12\n\n\x06PAYING\x10\x03\x42\xb2\x01\n\x1e\x63om.qwak.ai.administration.apiP\x01Z\x8d\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0b\x06proto3')

_QWAKENVIRONMENTSTATUS = DESCRIPTOR.enum_types_by_name['QwakEnvironmentStatus']
QwakEnvironmentStatus = enum_type_wrapper.EnumTypeWrapper(_QWAKENVIRONMENTSTATUS)
_ACCOUNTTIER = DESCRIPTOR.enum_types_by_name['AccountTier']
AccountTier = enum_type_wrapper.EnumTypeWrapper(_ACCOUNTTIER)
ENVIRONMENT_STATUS_INVALID = 0
ENVIRONMENT_STATUS_ACTIVE = 1
ENVIRONMENT_STATUS_DISABLED = 2
ACCOUNT_TIER_INVALID = 0
FREE = 1
VALIDATED = 2
PAYING = 3


_QWAKENVIRONMENT = DESCRIPTOR.message_types_by_name['QwakEnvironment']
_ENVIRONMENTAPPLICATIONUSERCREDENTIALS = DESCRIPTOR.message_types_by_name['EnvironmentApplicationUserCredentials']
QwakEnvironment = _reflection.GeneratedProtocolMessageType('QwakEnvironment', (_message.Message,), {
  'DESCRIPTOR' : _QWAKENVIRONMENT,
  '__module__' : 'qwak.administration.v0.environments.environment_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.QwakEnvironment)
  })
_sym_db.RegisterMessage(QwakEnvironment)

EnvironmentApplicationUserCredentials = _reflection.GeneratedProtocolMessageType('EnvironmentApplicationUserCredentials', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTAPPLICATIONUSERCREDENTIALS,
  '__module__' : 'qwak.administration.v0.environments.environment_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.EnvironmentApplicationUserCredentials)
  })
_sym_db.RegisterMessage(EnvironmentApplicationUserCredentials)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.administration.apiP\001Z\215\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0'
  _QWAKENVIRONMENT.fields_by_name['tenant_id']._options = None
  _QWAKENVIRONMENT.fields_by_name['tenant_id']._serialized_options = b'\030\001'
  _QWAKENVIRONMENTSTATUS._serialized_start=1094
  _QWAKENVIRONMENTSTATUS._serialized_end=1213
  _ACCOUNTTIER._serialized_start=1215
  _ACCOUNTTIER._serialized_end=1291
  _QWAKENVIRONMENT._serialized_start=332
  _QWAKENVIRONMENT._serialized_end=1034
  _ENVIRONMENTAPPLICATIONUSERCREDENTIALS._serialized_start=1036
  _ENVIRONMENTAPPLICATIONUSERCREDENTIALS._serialized_end=1092
# @@protoc_insertion_point(module_scope)
