"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import jfml.hosting_gateway.v1.build_upload_url_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetBuildVersioningUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> jfml.hosting_gateway.v1.build_upload_url_pb2.BuildUploadUrlParameters:
        """The params to define the url."""
    def __init__(
        self,
        *,
        params: jfml.hosting_gateway.v1.build_upload_url_pb2.BuildUploadUrlParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetBuildVersioningUploadURLRequest = GetBuildVersioningUploadURLRequest

class GetBuildVersioningUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the upload"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["upload_url", b"upload_url"]) -> None: ...

global___GetBuildVersioningUploadURLResponse = GetBuildVersioningUploadURLResponse
