# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/external/prometheus_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMqwak/administration/runtime_configuration/v0/external/prometheus_config.proto\x12Gqwak.administration.runtime_configuration.v0.external.prometheus_config\"\x97\x01\n\x17PrometheusConfiguration\x12n\n\x06promxy\x18\x01 \x01(\x0b\x32\\.qwak.administration.runtime_configuration.v0.external.prometheus_config.PromxyConfigurationH\x00\x42\x0c\n\nproxy_type\"\"\n\x13PromxyConfiguration\x12\x0b\n\x03url\x18\x01 \x01(\tB\xf9\x01\n@com.jfrog.ml.runtime_configuration.v0.external.prometheus_configP\x01Z\xb2\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_externalb\x06proto3')



_PROMETHEUSCONFIGURATION = DESCRIPTOR.message_types_by_name['PrometheusConfiguration']
_PROMXYCONFIGURATION = DESCRIPTOR.message_types_by_name['PromxyConfiguration']
PrometheusConfiguration = _reflection.GeneratedProtocolMessageType('PrometheusConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _PROMETHEUSCONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.external.prometheus_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.external.prometheus_config.PrometheusConfiguration)
  })
_sym_db.RegisterMessage(PrometheusConfiguration)

PromxyConfiguration = _reflection.GeneratedProtocolMessageType('PromxyConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _PROMXYCONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.external.prometheus_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.external.prometheus_config.PromxyConfiguration)
  })
_sym_db.RegisterMessage(PromxyConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n@com.jfrog.ml.runtime_configuration.v0.external.prometheus_configP\001Z\262\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_external'
  _PROMETHEUSCONFIGURATION._serialized_start=155
  _PROMETHEUSCONFIGURATION._serialized_end=306
  _PROMXYCONFIGURATION._serialized_start=308
  _PROMXYCONFIGURATION._serialized_end=342
# @@protoc_insertion_point(module_scope)
